EXT_AUTH_AAD_CLIENT_ID = None
EXT_AUTH_AAD_TENANT_ID = None
EXT_AUTH_AAD_AUTH_AUTHORITY = None
EXT_AUTH_AAD_CLIENT_SECRET = None
EXT_AUTH_AAD_REDIRECT_URI = '/auth/callback'
EXT_AUTH_AAD_AUTH_FLOW_KEY = "aad_auth_flow"
EXT_AUTH_AAD_ACCESS_TOKEN_KEY = "access_token"
EXT_AUTH_AAD_TOKEN_CACHE_KEY = 'aad_token_cache'
EXT_AUTH_POST_LOGIN_REDIRECT_URI = ''
EXT_AUTH_AAD_SCOPES = ["user.read", "user.read.all"]
